#
# spec file for package python-openapi-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# python-Django is not present in SLE 16
%if 0%{suse_version} >= 1699
%bcond_without django
%endif

Name:           python-openapi-core
Version:        0.19.4
Release:        1.2
Summary:        Client- and server-side support for the OpenAPI Specification v3
License:        BSD-3-Clause
URL:            https://github.com/p1c2u/openapi-core
Source:         https://github.com/p1c2u/openapi-core/archive/%{version}.tar.gz#/openapi-core-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module WebOb}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module aiohttp >= 3}
BuildRequires:  %{python_module asgiref >= 3.6.0}
BuildRequires:  %{python_module falcon >= 3.0}
BuildRequires:  %{python_module isodate}
BuildRequires:  %{python_module jsonschema >= 4.18.0 with %python-jsonschema < 5}
BuildRequires:  %{python_module jsonschema-path >= 0.3.1 with %python-jsonschema-path < 0.4}
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module multidict >= 6.0.4}
BuildRequires:  %{python_module openapi-schema-validator >= 0.6 with %python-openapi-schema-validator < 0.7}
BuildRequires:  %{python_module openapi-spec-validator >= 0.7.1 with %python-openapi-spec-validator < 0.8}
BuildRequires:  %{python_module parse}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module responses}
%if %{with django}
BuildRequires:  %{python_module Django}
%endif
# /SECTION
Requires:       python-Werkzeug
Requires:       python-asgiref >= 3.6.0
Requires:       python-isodate
Requires:       python-more-itertools
Requires:       python-parse
Requires:       (python-jsonschema >= 4.18.0 with python-jsonschema < 5)
Requires:       (python-jsonschema-path >= 0.3.1 with python-jsonschema-path < 0.4)
Requires:       (python-openapi-schema-validator >= 0.6 with python-openapi-schema-validator < 0.7)
Requires:       (python-openapi-spec-validator >= 0.7.1 with python-openapi-spec-validator < 0.8)
BuildArch:      noarch
%python_subpackages

%description
Openapi-core is a Python library that adds client-side
and server-side support for the OpenAPI Specification
v3.0.0.

%prep
%setup -q -n openapi-core-%{version}
sed -i '/--cov/d' pyproject.toml
for f in openapi_core/contrib/falcon/views.py; do
  [ -f $f -a ! -s $f ] && echo "# empty module" > $f || exit 1
done

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%if !%{with django}
rm -v tests/unit/contrib/django/test_django.py
%endif
%pytest tests/unit -k 'not (test_read_only_properties_invalid or test_write_only_properties_invalid)'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/openapi_core
%{python_sitelib}/openapi_core-%{version}*-info

%changelog
* Fri Sep 27 2024 Markéta Machová <mmachova@suse.com>
- reformat the django test constraints
* Fri Sep 27 2024 Dirk Müller <dmueller@suse.com>
- update to 0.19.4:
  * Starlette 0.38.x support #906
  * Fix resolvers not updating properly when referencing other
    files. #894
  * Fix RequestUnmarshalResult body type #900
  * Fix Starlette streaming response for HTTPMiddleware #906
- update to 0.19.3:
  * Fix resolver for jsonschema validator created by
    SchemaValidatorsFactory #853
  * Use `base_uri` from schema path for spec validation #859
  * Openapi 3.0 unmarshalling None with nullable subschema fix
    [#876]
- update to 0.19.2:
  * Falcon multi-value query parameters fix #830
  * Fix a DeprecationWarning from aiohttp in TestPetPhotoView
  * Fix hyphen characters in path parameters #851
- update to 0.19.1:
  * Path finder cls configuration #797
  * Invalid usage of super() when having multi-baseclass
    inheritance: … #802
  * Fix content-type when no space after semicolon #814
  * Protocols body and data attributes docstrings fix #829
- update to 0.19.0:
  * FastAPI integration #738
  * Mimetype parameters (i.e. charset) handling #678
  * Parameter deserializers renamed to Style deserializers #676
  * Unmarshalling processor enhancement #625
  * Option to skip response validation in Django, Falcon and
    Flask integrations #667
  * use explicit arguments (instead of kwargs) in Spec.from_dict
    and add short note in documentation how to use base_url for
    Spec.from_dict
  * Parameter and header get value refactor #677
  * Python 3.12 support #684
  * Bump openapi-spec-validator from 0.6.0 to 0.7.0 #685
  * Use openapi-spec-validator spec version finder #691
  * Move to `SchemaPath` from jsonschema-path package #690
  * Specification validation as part of shortcuts #686
  * Style deserializing reimplementation with support for all
    styles #694
  * Media type encoding support #646
  * Replace `mimetype` with `content_type` to include content
    parameters #699
  * Suport for primitive properties casting of urlencoded
    objects. #701
  * Request response binary format support #710
  * Starlette middleware #680
  * OpenAPI app and high level integration #716
  * aiohttp request host_url include scheme #673
  * aiohttp response body check none #674
  * Validate empty request body fix #713
  * Path finder returns default server #648
  * OpenAPI config passed to validators and unmarshallers fix
  * milti types schema format unmarshal fix #562
* Thu Sep 26 2024 Markéta Machová <mmachova@suse.com>
- Exclude django tests for non-Factory
* Tue Feb  6 2024 Ben Greiner <code@bnavigator.de>
- Skip python312: No compatible jsonschema-spec available. We are
  waiting for a release that migrated to jsonschema-path
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 0.18.2:
  * Deprecated spec validator fix + warnings resolved #717
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.18.1
  [#]# Bug fixes
  * Ignore formats for other types in unmarshalling process #599
  [#]# Features
  * More media types supported #622
  * Unmarshalling customizations in middlewares
    (FalconOpenAPIMiddleware, FlaskOpenAPIView,
    FlaskOpenAPIViewDecorator) #623
* Sat Jul 29 2023 Ben Greiner <code@bnavigator.de>
- Fix requirements
* Tue Jul 25 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.18.0:
  * Compatibility with jsonschema 4.18, jsonschema-spec 0.2,
    openapi-schema-validator 0.6 and openapi-spec-validator 0.6 #597
  * spec_url parameter of Spec.from_dict is deprecated. Use base_uri
    instead. #597
  * ref_resolver_handlers parameter of Spec.from_dict is deprecated. Use
    handlers instead. #597
  * Drop python 3.7 support #595
  * Format validators ignore other types and pass (in accordance with the
    specification) #597
  * shortcuts high level public api expose #465
  * ParametersError context property deprecated #462
  * Spec.create deprecated #463
  * Validators refactor #457
  * Webhooks support #470
  * Rename UnmarshalContext to ValidationContext #472
  * Fix PATH_PARAMETER_PATTERN for DRF default value pattern. #468
  * Fix falcon response data none #471
  * Shortcuts backward compatible #482
  * RequestValidator and ResponseValidator backward compatibility #487
  * Fix flask decorator function return other types #489
  * Fix integration Request Response factories check types fix #490
  * Fix Requests request dont allow fragments #491
  * Fix openapi packages update and tests #498
  * unmarshallers integration tests #497
  * Unmarshallers and validators refactor #508
  * Shortcuts refactor #517
  * Media type deserializers refactor #518
  * Schema unmarshalling/validation returns Invalid* exception (InvalidData,
    InvalidParameter, InvalidRequestBody, InvalidHeader). Use __cause__
    property to get root cause exception.
  * InvalidSecurity exception renamed to SecurityNotFound
* Tue Jun 20 2023 Ben Greiner <code@bnavigator.de>
- Revert to 0.16.x branch
  * python-jupyterlab-server-openapi (jupyterlab-server[openapi])
  is the only consumer in the distribution and requires
  openapi-core~=0.16.1
  * See gh#jupyterlab/jupyterlab_server#400
- Changelog from 0.16.1 to 0.16.6:
  * openapi-schema-validator 0.5.2 tests compatibility fix #527
  * validators public api expose #455
  * allow openapi-schema-validator 0.4 #458
  * better unmarshaller finders with refactor #447
  * werkzeug flask root path fix #449
  * additionalProperties without schema should allow null. #444
  * Add NullUnmarshaller #432
  * Multi type unmarshaller #433
  * Unmarshaller format refactor #434
* Tue Jun 20 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.17.2:
  * Integrations: Add support for aiohttp.web #571
  * Include tests in sdist archives #537
  * add python 3.11 support #538
  * shortcuts high level public api expose #465
  * ParametersError context property deprecated #462
  * Spec.create deprecated #463
  * Validators refactor #457
  * Webhooks support #470
  * Rename UnmarshalContext to ValidationContext #472
  * Fix PATH_PARAMETER_PATTERN for DRF default value pattern. #468
  * Fix falcon response data none #471
  * Shortcuts backward compatible #482
  * RequestValidator and ResponseValidator backward compatibility #487
  * Fix flask decorator function return other types #489
  * Fix integration Request Response factories check types fix #490
  * Fix Requests request dont allow fragments #491
  * Fix openapi packages update and tests #498
  * unmarshallers integration tests #497
  * Unmarshallers and validators refactor #508
  * Shortcuts refactor #517
  * Media type deserializers refactor #518
  * validators public api expose #455
  * allow openapi-schema-validator 0.4 #458
  * better unmarshaller finders with refactor #447
  * werkzeug flask root path fix #449
  * additionalProperties without schema should allow null. #444
- Switch back to PyPI tarball.
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.16.2:
  Add NullUnmarshaller #432
  Multi type unmarshaller #433
  Unmarshaller format refactor #434
- Update to 0.16.1:
  lists as additional properties fix #429
  x-model extension optional #431
* Thu Oct  6 2022 Benjamin Greiner <code@bnavigator.de>
- Fix dependencies.
* Wed Oct  5 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.16.0:
  * Switch to jsonschema-spec #416
  * Use auto-detect validator proxy #418
  * OpenAPI 3.1 support + Auto-detect proxies and request / response
    validator protocols #419
  * Add py.typed to mark package as supporting typing #420
  * Refuse to cast str or bytes to array #421
  * x-model extension import model class #422
  * Add deepObject support #379
  * Add anyOf support #423
  * Separate werkzeug support #426
  * Starlette support #427
  * Parameter deserialize complex scenario support (#329)
  * Response headers support (#332)
  * Response headers support for contrib (#333)
  * Drop python 2.7 support (#335 #344 #351)
  * Drop python 3.5 support (#339)
  * Drop python 3.6 support #383
  * Add python 3.10 support #383
  * Falcon2 support drop (#353)
  * Django2 support drop (#358)
  * Support basic re_path for Django integration (#337)
  * unused NoValue type removed (#340)
  * attrs remove and use dataclasses backport for python 3.6 (#345)
  * Request validation parameters dataclass (#346)
  * Handle missing MIME type in MediaTypeFinder (#371)
  * Limit openapi dependencies upper bounds #386
  * switch to pathable #389
  * Get rid of create_spec shortcut #393
  * Request and Response protocols #407
  * validator factories removed from validation shortcuts #408
  * Predefined openapi validators #409
- Drop Python 2 parts.
- Fix {Build,}Requires.
* Mon Aug 16 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.14.2
  * Non required request body fix (#325)
  * Parameter simple scenarion for any schema type fix (#323)
- Release notes for 0.14.0
  Changes:
  * Spec replaced with SpecPath (#318)
  Backward incompatibilities:
  * create_spec shortcut returns SpecPath instead of Spec
  * removed Spec-related schema package
  * schema-related exceptions moved to top level exceptions module
  * readOnly/writeOnly invalid properties raise error (before were
    ommitted)
  * MediaTypeDeserializersFactory.create expects mimetype string
    instead of media_type
  * MediaTypeFinder.find returns media_type, mimetype tuple instead
    of just media_type
- Changelog between 0.13.3 and 0.14.0:
  https://github.com/p1c2u/openapi-core/releases
- Edit out mock test requirement for Python 3
* Tue May  5 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip one test so we can use pytest5
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 0.13.3
  * lot of changes, see
    https://github.com/p1c2u/openapi-core/releases
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Properly conditionalize the python2 drop so it lets us backport
  the packages
* Thu Jan  9 2020 Todd R <toddrme2178@gmail.com>
- Drop python2 subpackage due to dropping backports dependencies.
* Thu Sep 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.12.0:
  * OAS validation with JSONSchema (#157)
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.11.1:
  * Path item parameter override (#145)
  * Separate cast and unmarshal (#156)
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.11.0:
  * End of Python 3.4 support (#136)
  * Add support for one-of with any type (#133)
  * Modify FlaskOpenAPIRequest to accommodate path variables (#141)
  * Primitive types unmarshallers (#138)
  * attr errors hashable fix (#143)
  * Parameters on path item object support (#144)
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.10.0:
  * Various tests and support updates
- Update requirements to match up upstream
* Wed Aug  8 2018 tchvatal@suse.com
- Switch to github tarball to get tests
- Run the tests
* Mon Jul 30 2018 sean.marlow@suse.com
- Initial release v0.5.0
